itchatmp
========

|Python2| |Python3|

itchatmp is an open source api for WeChat massive platfrom, a commonly-used Chinese social networking app.

Accessing your personal wechat account through itchat in python has never been easier.

itchatmp based on tornado framework, process efficiently. It supports normal uses, nginx reverse proxy and wsgi uses.

.. |Python2| image:: https://img.shields.io/badge/python-2.7-ff69b4.svg
.. |Python3| image:: https://img.shields.io/badge/python-3.5-red.svg
